package cupidonline.model;

import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.SortedSet;
import java.util.TreeSet;
import java.util.stream.Collectors;

public class MyCupido extends Cupido {
	public MyCupido(Map<String, Persona> iscritti, Map<String, Preferenza> preferenze) {
		super(iscritti, preferenze);
	}
	
	public SortedSet<Corrispondenza> trovaCorrispondenze(String pName, Preferenza pPref){
		return getIscritti().stream()
								.filter(q->!(q.getId().equals(pName)))
								.filter(q->verificaSesso(q,pPref))
								.map(q->calcolaCorrispondenza(q,pPref,pName))
								.collect(Collectors.toCollection(TreeSet::new));
	}
	
	public SortedSet<Corrispondenza> trovaCorrispondenzeAlternativo(String pName, Preferenza pPref){
		TreeSet<Corrispondenza> t = new TreeSet<>();
		for (Persona q : getIscritti()) {
			if (verificaSesso(q,pPref)) {
				Corrispondenza corr = calcolaCorrispondenza(q,pPref,pName);
				t.add(corr);
			}
		}
		return t;
	}
	
	@Override
	public int indiceCompatibilità(Persona q, Preferenza pref) {
		// età: 100% se nel range, -5% per ogni anno fuori range;
		int indexRange = pref.etaInRange(q.getEta()) ? 100 : 100-5*pref.etaOutOfRange(q.getEta());
		// System.out.println("indexRange: " + indexRange);
		// segno zodiacale: 100% se identico a quello richiesto, 90% altrimenti;
		int indexSegno = pref.getSegnoZodiacale().isPresent() ? (q.getSegnoZodiacale()==pref.getSegnoZodiacale().get() ? 100 : 90) : 100;
		// System.out.println("indexSegno: " + indexSegno);
		// zona di residenza: 100% nella città, 90% nella provincia, 60% nella regione, 40% fuori regione;
		int indexLoc = pref.getCitta().equalsIgnoreCase(q.getCitta()) ? 100 :
						 pref.getProvincia().equalsIgnoreCase(q.getProvincia()) ? 90 :
							pref.getRegione().equalsIgnoreCase(q.getRegione()) ? 60 : 40;
		// System.out.println("indexLoc: " + indexLoc);
		// caratteristiche fisiche dimensionali: 100% se identico a quello richiesto o non specificato, altrimenti -1% per ogni cm o kg di differenza (distanza minima);
		int indexAltezza = pref.getAltezza().isPresent() ? (q.getAltezza()==pref.getAltezza().get() ? 100 : 100-Math.round(100*(Math.abs(q.getAltezza()-pref.getAltezza().get())))) : 100;
		// System.out.println("indexAltezza: " + indexAltezza);
		int indexPeso = pref.getPeso().isPresent() ? (q.getPeso()==pref.getPeso().getAsInt() ? 100 : 100-Math.round(Math.abs(q.getPeso()-pref.getPeso().getAsInt()))) : 100;
		// System.out.println("indexPeso: " + indexPeso);
		// caratteristiche fisiche adimensionali: 100% se identico a quello richiesto o non specificato, 95% altrimenti
		int indexColoreCapelli = pref.getColoreCapelli().isPresent() ? (q.getColoreCapelli()==pref.getColoreCapelli().get() ? 100 : 95) : 100;
		// System.out.println("indexColoreCapelli: " + indexColoreCapelli);
		int indexColoreOcchi = pref.getColoreOcchi().isPresent() ? (q.getColoreOcchi()==pref.getColoreOcchi().get() ? 100 : 95) : 100;
		// System.out.println("indexColoreOcchi: " + indexColoreOcchi);
		// partner, prendendo il valore minimo fra i seguenti sotto-indici:
		return List.of(indexRange,indexSegno, indexLoc, indexAltezza, indexPeso, indexColoreCapelli,indexColoreOcchi).stream().min(Comparator.comparing(Integer::valueOf)).get();
		
	}
	
}
